==> fap_0.8.8.orig.tar.bz2: fap-0.8.8/src/gui/mainWindow.h <==
/*
 *  Copyright (C) 2006-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <fx.h>

#include "audio.h"
#include "input.h"
#include "bookmark.h"
#include "playlist.h"
#include "timeDisplay.h"
#include "infoLabel.h"
//#include "trackList/trackList.h"

/*****************************************************************/

class loadThread : public FXThread {
private:
	input		*_i;
	FXString	_name;
	FXGUISignal	*_loaded;

protected:
	FXint run();

public:
	loadThread(input* i, FXString name, FXGUISignal *loaded) :
		FXThread(), _i(i), _name(name), _loaded(loaded) {};

	~loadThread() { delete _loaded; }
};

/*****************************************************************/

class mainWindow : public FXMainWindow {
	FXDECLARE(mainWindow)

private:
	FXIcon		*ledRedIcon;
	FXIcon		*ledYellowIcon;
	FXIcon		*ledGreenIcon;

	FXToolBar		*_toolbar;
	FXStatusBar		*_statusbar;
	FXHorizontalFrame	*_mainView;
	infoLabel		*_songInfo;
	timeLabel		*_songTime;
	timeDisplay		*_timeDisplay;
	FXDirList		*_dirList;
	playlist		*_playList;
	bookmark		*_bookmarkList;
	FXListBox		*_fileTypes;
	FXToggleButton		*_playMode;
	FXToggleButton		*_editMode;
	FXButton		*_playpause;

	FXint		_width;
	FXint		_height;

	input		*_input;
	input		*_preload;
	audio		*_audio;

	loadThread	*_loadThread;
	bool		_playing;
	FXString	_preloaded;
	FXString	_playDir;

private:
	mainWindow() {};
	mainWindow(const mainWindow&);
	mainWindow& operator=(const mainWindow&);

	void setDisplay();

	void clearDisplay(const bool loading);

	void setFile(const FXString& file, const bool play);

	void load(const FXString& filename, input* const i, void* data=0);

	void setOpts();

	void setBackend(const int val, const int refresh=1);

	input* backend(const int val);

	void notify();

	void setPlayButton();

public:
	mainWindow(FXApp*);
	virtual ~mainWindow();
	virtual void create();
	virtual FXbool close(FXbool notify=FALSE);

public:
	enum{
		ID_DIRLIST=FXMainWindow::ID_LAST,
		ID_PLAYLIST,
		ID_BOOKMARKS,
		ID_FILETYPE,
		ID_SONG_LOADED,
		ID_AUDIO_MSG,
		ID_TIME,
		ID_LED,
		ID_UI_MODE,
		ID_PLAY,
		ID_STOP,
		ID_PAUSE,
		ID_PREV,
		ID_NEXT,
		ID_PREV_SUBTUNE,
		ID_NEXT_SUBTUNE,
		ID_SUBTUNE,
		ID_PLSONG,
		ID_BM_ADD,
		ID_PL_ADD,
		ID_OPT_CONFIG,
		ID_INFO,
		ID_ABOUT,
		ID_PL_BACK,
		ID_PL_EDIT,
		ID_PL_SAVE,
		ID_VOL,
		ID_MESSAGE,
		ID_HOME,
		ID_LAST,
	};

public:
	long onAudioMsg(FXObject*, FXSelector, void*);
	long onCmdDirList(FXObject*, FXSelector, void*);
	long onRgtClkDirList(FXObject*, FXSelector, void*);
	long onCmdPlaySong(FXObject*, FXSelector, void*);
	long onCmdStopSong(FXObject*, FXSelector, void*);
	long onCmdPauseSong(FXObject*, FXSelector, void*);
	long onCmdChangeSong(FXObject*, FXSelector, void*);
	long onCmdSongSelected(FXObject*, FXSelector, void*);
	long onCmdAddItem(FXObject*, FXSelector, void*);
	long onCmdBmDel(FXObject*, FXSelector, void*);
	long onCmdBmClear(FXObject*, FXSelector, void*);
	long onCmdBmGet(FXObject*, FXSelector, void*);
	long onCmdConfig(FXObject*, FXSelector, void*);
	long onCmdFiletype(FXObject*, FXSelector, void*);
	long onUpdFiletype(FXObject*, FXSelector, void*);
	long onCmdInfo(FXObject*, FXSelector, void*);
	long onCmdUIMode(FXObject*, FXSelector, void*);
	long onCmdSongLoaded(FXObject*, FXSelector, void*);
	long onUpdSubtune(FXObject*, FXSelector, void*);
	long onCmdSubtune(FXObject*, FXSelector, void*);
	long onUpdLed(FXObject*, FXSelector, void*);
	long onCmdPlBack(FXObject*, FXSelector, void*);
	long onCmdPlEdit(FXObject*, FXSelector, void*);
	long onCmdPlSave(FXObject*, FXSelector, void*);
	long onCmdVol(FXObject*, FXSelector, void*);
	long onMessage(FXObject*, FXSelector, void*);
	long onHome(FXObject*, FXSelector, void*);
};

#endif

==> fap-0.9.0pre1.tar.bz2: fap-0.9.0pre1/src/gui/mainWindow.h <==
/*
 *  Copyright (C) 2006-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <fx.h>

#include "audio.h"
#include "input.h"
#include "bookmark.h"
#include "playlist.h"
#include "timeDisplay.h"
#include "infoLabel.h"
//#include "trackList/trackList.h"

/*****************************************************************/

class loadThread : public FXThread {
private:
	input		*_i;
	FXString	_name;
	FXGUISignal	*_loaded;

protected:
	FXint run();

public:
	loadThread(input* i, FXString name, FXGUISignal *loaded) :
		FXThread(), _i(i), _name(name), _loaded(loaded) {};

	~loadThread() { delete _loaded; }
};

/*****************************************************************/

class mainWindow : public FXMainWindow {
	FXDECLARE(mainWindow)

private:
	FXIcon		*ledRedIcon;
	FXIcon		*ledYellowIcon;
	FXIcon		*ledGreenIcon;

	FXToolBar		*_toolbar;
	FXStatusBar		*_statusbar;
	FXHorizontalFrame	*_mainView;
	infoLabel		*_songInfo;
	timeLabel		*_songTime;
	timeDisplay		*_timeDisplay;
	FXDirList		*_dirList;
	playlist		*_playList;
	bookmark		*_bookmarkList;
	FXListBox		*_fileTypes;
	FXToggleButton		*_playMode;
	FXToggleButton		*_editMode;
	FXButton		*_playpause;

	FXint		_width;
	FXint		_height;

	input		*_input;
	input		*_preload;
	audio		*_audio;

	loadThread	*_loadThread;
	bool		_playing;
	FXString	_preloaded;
	FXString	_playDir;

private:
	mainWindow() {};
	mainWindow(const mainWindow&);
	mainWindow& operator=(const mainWindow&);

	void setDisplay();

	void clearDisplay(const bool loading);

	void setFile(const FXString& file, const bool play);

	void load(const FXString& filename, input* const i, void* data=0);

	void setOpts();

	void setBackend(const int val, const int refresh=1);

	input* backend(const int val);

	void notify();

	void setPlayButton();

public:
	mainWindow(FXApp*);
	virtual ~mainWindow();
	virtual void create();
	virtual FXbool close(FXbool notify=FALSE);

public:
	enum{
		ID_DIRLIST=FXMainWindow::ID_LAST,
		ID_PLAYLIST,
		ID_BOOKMARKS,
		ID_FILETYPE,
		ID_SONG_LOADED,
		ID_AUDIO_MSG,
		ID_TIME,
		ID_LED,
		ID_UI_MODE,
		ID_PLAYPAUSE,
		ID_STOP,
		ID_PREV,
		ID_NEXT,
		ID_PREV_SUBTUNE,
		ID_NEXT_SUBTUNE,
		ID_SUBTUNE,
		ID_PLSONG,
		ID_BM_ADD,
		ID_PL_ADD,
		ID_OPT_CONFIG,
		ID_INFO,
		ID_ABOUT,
		ID_PL_BACK,
		ID_PL_EDIT,
		ID_PL_SAVE,
		ID_VOL,
		ID_MESSAGE,
		ID_HOME,
		ID_LAST,
	};

public:
	long onAudioMsg(FXObject*, FXSelector, void*);
	long onCmdDirList(FXObject*, FXSelector, void*);
	long onRgtClkDirList(FXObject*, FXSelector, void*);
	long onCmdPlayPauseSong(FXObject*, FXSelector, void*);
	long onCmdStopSong(FXObject*, FXSelector, void*);
	long onCmdChangeSong(FXObject*, FXSelector, void*);
	long onCmdSongSelected(FXObject*, FXSelector, void*);
	long onCmdAddItem(FXObject*, FXSelector, void*);
	long onCmdBmDel(FXObject*, FXSelector, void*);
	long onCmdBmClear(FXObject*, FXSelector, void*);
	long onCmdBmGet(FXObject*, FXSelector, void*);
	long onCmdConfig(FXObject*, FXSelector, void*);
	long onCmdFiletype(FXObject*, FXSelector, void*);
	long onUpdFiletype(FXObject*, FXSelector, void*);
	long onCmdInfo(FXObject*, FXSelector, void*);
	long onCmdUIMode(FXObject*, FXSelector, void*);
	long onCmdSongLoaded(FXObject*, FXSelector, void*);
	long onUpdSubtune(FXObject*, FXSelector, void*);
	long onCmdSubtune(FXObject*, FXSelector, void*);
	long onUpdLed(FXObject*, FXSelector, void*);
	long onCmdPlBack(FXObject*, FXSelector, void*);
	long onCmdPlEdit(FXObject*, FXSelector, void*);
	long onCmdPlSave(FXObject*, FXSelector, void*);
	long onCmdVol(FXObject*, FXSelector, void*);
	long onMessage(FXObject*, FXSelector, void*);
	long onHome(FXObject*, FXSelector, void*);
};

#endif
